@@ -24,35 +24,43 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KCMKNotesSummary, "kcmknotessummary.json")
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KCMKNotesSummary::KCMKNotesSummary(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
+#else
+KCMKNotesSummary::KCMKNotesSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+#endif
 {
     initGUI();
 
     connect(mCheckedCollectionWidget->folderTreeView(), &QAbstractItemView::clicked, this, &KCMKNotesSummary::modified);
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     KAcceleratorManager::manage(this);
+#else
+    KAcceleratorManager::manage(widget());
+#endif
 
     load();
-
-    auto about = new KAboutData(QStringLiteral("kcmknotessummary"),
-                                i18n("kcmknotessummary"),
-                                QString(),
-                                i18n("Notes Summary Configuration Dialog"),
-                                KAboutLicense::GPL,
-                                i18n("Copyright © 2013-%1 Laurent Montel <montel@kde.org>", QStringLiteral("2023")));
-    about->addAuthor(ki18n("Laurent Montel").toString(), QString(), QStringLiteral("montel@kde.org"));
-    setAboutData(about);
 }
 
 void KCMKNotesSummary::modified()
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(true);
+#else
+    markAsChanged();
+#endif
 }
 
 void KCMKNotesSummary::initGUI()
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto layout = new QVBoxLayout(this);
+#else
+    auto layout = new QVBoxLayout(widget());
+#endif
     layout->setContentsMargins(0, 0, 0, 0);
 
     mCheckedCollectionWidget = new PimCommon::CheckedCollectionWidget(Akonadi::NoteUtils::noteMimeType());
@@ -63,7 +71,11 @@ void KCMKNotesSummary::initFolders()
 {
     KSharedConfigPtr _config = KSharedConfig::openConfig(QStringLiteral("kcmknotessummaryrc"));
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
+#else
+    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), widget());
+#endif
     mModelState->setSelectionModel(mCheckedCollectionWidget->selectionModel());
 }
 
@@ -84,19 +96,30 @@ void KCMKNotesSummary::load()
     initFolders();
     loadFolders();
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(false);
+#else
+    setNeedsSave(false);
+#endif
 }
 
 void KCMKNotesSummary::save()
 {
     storeFolders();
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(false);
+#else
+    setNeedsSave(false);
+#endif
 }
 
 void KCMKNotesSummary::defaults()
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(true);
+#else
+    markAsChanged();
+#endif
 }
 
 #include "kcmknotessummary.moc"
